@@ -2,13 +2,13 @@
 
 from . import _version, adjustment
 from .api import Api
-from .structure import Structure
-from .tenant import Tenant
 from .example import (
-    example_structure,
-    example_structure_to_file,
     example_api,
     example_api_to_file,
+    example_structure,
+    example_structure_to_file,
 )
+from .structure import Structure, Ts, TsTree
+from .tenant import Tenant
 
 __version__ = _version.get_versions()["version"]
